pm4py.algo.discovery.temporal\_profile.variants package
=======================================================

Submodules
----------

pm4py.algo.discovery.temporal\_profile.variants.dataframe module
----------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.temporal_profile.variants.dataframe
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.temporal\_profile.variants.log module
----------------------------------------------------------

.. automodule:: pm4py.algo.discovery.temporal_profile.variants.log
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.temporal_profile.variants
   :members:
   :undoc-members:
   :show-inheritance:
